==> griptape_nodes-0.36.0-py3-none-any.whl: griptape_nodes/drivers/storage/local_storage_driver.py <==
import logging
from urllib.parse import urljoin

import httpx

from griptape_nodes.app.app import STATIC_SERVER_ENABLED, STATIC_SERVER_HOST, STATIC_SERVER_PORT, STATIC_SERVER_URL
from griptape_nodes.drivers.storage.base_storage_driver import BaseStorageDriver, CreateSignedUploadUrlResponse

logger = logging.getLogger("griptape_nodes")


class LocalStorageDriver(BaseStorageDriver):
    """Stores files using the engine's local static server."""

    def __init__(self, base_url: str | None = None) -> None:
        """Initialize the LocalStorageDriver.

        Args:
            base_url: The base URL for the static file server. If not provided, it will be constructed
        """
        if not STATIC_SERVER_ENABLED:
            msg = "Static server is not enabled. Please set STATIC_SERVER_ENABLED to True."
            raise ValueError(msg)
        if base_url is None:
            self.base_url = f"http://{STATIC_SERVER_HOST}:{STATIC_SERVER_PORT}{STATIC_SERVER_URL}"
        else:
            self.base_url = base_url

    def create_signed_upload_url(self, file_name: str) -> CreateSignedUploadUrlResponse:
        static_url = urljoin(self.base_url, "/static-upload-urls")
        try:
            response = httpx.post(static_url, json={"file_name": file_name})
            response.raise_for_status()
        except httpx.HTTPStatusError as e:
            msg = f"Failed to create presigned URL for file {file_name}: {e}"
            logger.error(msg)
            raise RuntimeError(msg) from e

        response_data = response.json()
        url = response_data.get("url")
        if url is None:
            msg = f"Failed to create presigned URL for file {file_name}: {response_data}"
            logger.error(msg)
            raise ValueError(msg)

        return {"url": url, "headers": response_data.get("headers", {}), "method": "PUT"}

    def create_signed_download_url(self, file_name: str) -> str:
        return urljoin(self.base_url, f"/static/{file_name}")

==> griptape_nodes-0.38.0-py3-none-any.whl: griptape_nodes/drivers/storage/local_storage_driver.py <==
import logging
import time
from urllib.parse import urljoin

import httpx

from griptape_nodes.app.app import STATIC_SERVER_ENABLED, STATIC_SERVER_HOST, STATIC_SERVER_PORT, STATIC_SERVER_URL
from griptape_nodes.drivers.storage.base_storage_driver import BaseStorageDriver, CreateSignedUploadUrlResponse

logger = logging.getLogger("griptape_nodes")


class LocalStorageDriver(BaseStorageDriver):
    """Stores files using the engine's local static server."""

    def __init__(self, base_url: str | None = None) -> None:
        """Initialize the LocalStorageDriver.

        Args:
            base_url: The base URL for the static file server. If not provided, it will be constructed
        """
        if not STATIC_SERVER_ENABLED:
            msg = "Static server is not enabled. Please set STATIC_SERVER_ENABLED to True."
            raise ValueError(msg)
        if base_url is None:
            self.base_url = f"http://{STATIC_SERVER_HOST}:{STATIC_SERVER_PORT}{STATIC_SERVER_URL}"
        else:
            self.base_url = base_url

    def create_signed_upload_url(self, file_name: str) -> CreateSignedUploadUrlResponse:
        static_url = urljoin(self.base_url, "/static-upload-urls")
        try:
            response = httpx.post(static_url, json={"file_name": file_name})
            response.raise_for_status()
        except httpx.HTTPStatusError as e:
            msg = f"Failed to create presigned URL for file {file_name}: {e}"
            logger.error(msg)
            raise RuntimeError(msg) from e

        response_data = response.json()
        url = response_data.get("url")
        if url is None:
            msg = f"Failed to create presigned URL for file {file_name}: {response_data}"
            logger.error(msg)
            raise ValueError(msg)

        return {"url": url, "headers": response_data.get("headers", {}), "method": "PUT"}

    def create_signed_download_url(self, file_name: str) -> str:
        url = urljoin(self.base_url, f"/static/{file_name}")
        # Add a cache-busting query parameter to the URL so that the browser always reloads the file
        cache_busted_url = urljoin(url, f"?t={int(time.time())}")
        return cache_busted_url
